CANNs Documentation / CANNs 文档
=================================

Welcome to the CANNs (Continuous Attractor Neural Networks) documentation!

欢迎来到 CANNs（连续吸引子神经网络）文档！

Choose Your Language / 选择语言
------------------------------

.. grid:: 2

    .. grid-item-card:: 🇺🇸 English
        :link: en/index
        :link-type: doc
        :class-header: bg-light
        
        Complete documentation in English
        
        * API Reference
        * Tutorials & Examples  
        * User Guide

    .. grid-item-card:: 🇨🇳 中文
        :link: zh/index
        :link-type: doc
        :class-header: bg-light
        
        中文版文档
        
        * API 参考（链接至英文版）
        * 教程和示例
        * 用户指南

.. toctree::
   :maxdepth: 2
   :caption: Languages / 语言:
   :hidden:

   English <en/index>
   中文 <zh/index>

About CANNs
-----------

CANNs is a Python library for modeling and analyzing continuous attractor neural networks. It provides tools for building, training, and analyzing various types of CANN models.

CANNs 是一个用于建模和分析连续吸引子神经网络的 Python 库。它提供了构建、训练和分析各种 CANN 模型的工具。